@@ -34,7 +34,11 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.051';
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
+
+our $VERSION = '0.078';
+
+=begin comment
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -57,6 +61,19 @@ sub __defining_string {
     return '?|';
 }
 
+=end comment
+
+=cut
+
+use constant DEF	=> {
+    '?|'	=> {
+	expl	=> 'Re-use capture group numbers',
+	intro	=> '5.009005',
+    },
+};
+
+__PACKAGE__->__setup_class();
+
 1;
 
 __END__
@@ -64,7 +81,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -72,7 +90,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
