@@ -43,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.070';
+our $VERSION = '0.078';
 
 sub __match_setup {
     my ( undef, $tokenizer ) = @_;	# Invocant unused
@@ -51,21 +51,23 @@ sub __match_setup {
     return;
 }
 
-__PACKAGE__->__setup_class( {
-	'??'	=> {
-	    expl	=> 'Evaluate code, use as regexp at this point',
-	    intro	=> '5.006',
-	},
-	'?p'	=> {
-	    expl	=> 'Evaluate code, use as regexp at this point (removed in 5.9.5)',
-	    intro	=> '5.005',	# Presumed. I can find no documentation.
-	    remov	=> '5.009005',
-	},
-	'?'		=> {
-	    expl	=> 'Evaluate code. Always matches.',
-	    intro	=> '5.005',
-	},
+use constant DEF	=> {
+    '??'	=> {
+	expl	=> 'Evaluate code, use as regexp at this point',
+	intro	=> '5.006',
     },
+    '?p'	=> {
+	expl	=> 'Evaluate code, use as regexp at this point (removed in 5.9.5)',
+	intro	=> '5.005',	# Presumed. I can find no documentation.
+	remov	=> '5.009005',
+    },
+    '?'		=> {
+	expl	=> 'Evaluate code. Always matches.',
+	intro	=> '5.005',
+    },
+};
+
+__PACKAGE__->__setup_class(
     {
 	suffix	=> '{',
     },
@@ -78,7 +80,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -86,7 +89,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
