@@ -44,7 +44,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.070';
+our $VERSION = '0.078';
 
 use constant VERSION_WHEN_IN_REGEX_SET => '5.017009';
 
@@ -83,10 +83,24 @@ sub perl_version_introduced {
     return $self->{perl_version_introduced};
 }
 
+# Normalize the content of an interpolation object before making it into
+# a PPI document. The issue here is that things like ${x} are at least
+# warnings outside strings, but are normal inside them.
 sub __ppi_normalize_content {
     my ( $self ) = @_;
-    ( my $content = $self->{content} ) =~
-	s/ \A ( [\@\$] ) [{] ( .* ) [}] \z /$1$2/smx;
+    my $content;
+    defined( $content = $self->content() )
+	or return $content;
+    # NOTE: perldata gives a regexp for this, but it requires Perl 5.10.
+    # I believe the following caputures the intent, except possibly for
+    # various weird combinations of '::' and "'".
+    $content =~
+	s/ \A
+	    ( \$ \# \$* | [\@\$] \$* )	# Sigil and possible casts
+	    [{] \s* (?: :: )* '?	# per perldata
+	    ( ^? (?: \w+ (?: (?: :: | ' ) \w+ )* (?: :: )? | [[:punct:]] ) )
+	    \s* [}] \z
+	/$1$2/smx;
     return $content;
 }
 
@@ -424,7 +438,8 @@ muster.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -432,7 +447,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
