@@ -54,7 +54,7 @@ use PPIx::Regexp::Token::Backreference	();
 use PPIx::Regexp::Token::Backtrack	();
 use PPIx::Regexp::Token::Recursion	();
 
-our $VERSION = '0.070';
+our $VERSION = '0.078';
 
 # Return true if the token can be quantified, and false otherwise
 
@@ -111,11 +111,13 @@ sub is_quantifier {
     );
 
     sub perl_version_introduced {
-	my ( $self ) = @_;
-	return $perl_version_introduced{ $self->content() } || MINIMUM_PERL;
+       my ( $self ) = @_;
+       return $self->{perl_version_introduced} ||
+           $perl_version_introduced{ $self->content() } ||
+           MINIMUM_PERL;
     }
 }
-
+    
 {
 
     my %delim = map { $_ => 1 } qw/ ( ) { } [ ] /;
@@ -221,20 +223,28 @@ sub is_quantifier {
 
 	    # A cookie for the next '}'.
 	    my $commas = 0;
+	    my $allow_digit = 1;
 	    $tokenizer->cookie( COOKIE_QUANT, sub {
 		    my ( $tokenizer, $token ) = @_;
 		    $token or return 1;
 
-		    # Of literals, we accept exactly one comma provided it
-		    # is not immediately after a '{'. We also accept
-		    # anything that matches '[0-9]';
+		    # Code for 5.33.6 and after.
+		    # We allow {,...}, and we allow space inside and
+		    # adjacent to the curlys, and around the comma if
+		    # any. But not interior to the numbers.
 		    if ( $token->isa( TOKEN_LITERAL ) ) {
 			my $character = $token->content();
-			if ( $character eq ',' ) {
-			    $commas++ and return;
-			    return $tokenizer->prior_significant_token(
-				'content' ) ne '{';
+			if ( $character =~ m/ \A \s \z /smx ) {
+			    # Digits only allowed if the prior
+			    # significant was an open curly or a comma.
+			    $allow_digit = $tokenizer->prior_significant_token(
+				'content' ) =~ m/ \A [{,] \z /smx; # }
+			    return 1;
 			}
+			$character eq ','
+			    and return( ! $commas++ );
+			$allow_digit
+			    or return;
 			return $character =~ m/ \A [0-9] \z /smx;
 		    }
 
@@ -350,7 +360,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -358,7 +369,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
