@@ -7,9 +7,18 @@ use base qw{ PPIx::Regexp::Support };
 
 use Carp qw{ carp croak confess };
 use PPIx::Regexp::Constant qw{
+    ARRAY_REF
+    CODE_REF
+    HASH_REF
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
     MINIMUM_PERL
+    REGEXP_REF
     TOKEN_LITERAL
     TOKEN_UNKNOWN
+    @CARP_NOT
 };
 use PPIx::Regexp::Token::Assertion		();
 use PPIx::Regexp::Token::Backreference		();
@@ -24,10 +33,12 @@ use PPIx::Regexp::Token::Control		();
 use PPIx::Regexp::Token::Delimiter		();
 use PPIx::Regexp::Token::Greediness		();
 use PPIx::Regexp::Token::GroupType::Assertion	();
+use PPIx::Regexp::Token::GroupType::Atomic_Script_Run	();
 use PPIx::Regexp::Token::GroupType::BranchReset	();
 use PPIx::Regexp::Token::GroupType::Code	();
 use PPIx::Regexp::Token::GroupType::Modifier	();
 use PPIx::Regexp::Token::GroupType::NamedCapture	();
+use PPIx::Regexp::Token::GroupType::Script_Run	();
 use PPIx::Regexp::Token::GroupType::Subexpression	();
 use PPIx::Regexp::Token::GroupType::Switch	();
 use PPIx::Regexp::Token::Interpolation		();
@@ -39,10 +50,14 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
-use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
+use PPIx::Regexp::Util qw{
+    is_ppi_regexp_element
+    __instance
+};
+
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.051';
+our $VERSION = '0.078';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -109,13 +124,17 @@ defined $DEFAULT_POSTDEREF
 	$errstr = undef;
 
 	exists $args{default_modifiers}
-	    and 'ARRAY' ne ref $args{default_modifiers}
+	    and ARRAY_REF ne ref $args{default_modifiers}
 	    and do {
 		$errstr = 'default_modifiers must be an array reference';
 		return;
 	    };
 
+	defined $args{postderef}
+	    and __PACKAGE__->_deprecation_notice( attribute => 'postderef' );
+
 	my $self = {
+	    index_locations => $args{index_locations},	# Index locations
 	    capture => undef,	# Captures from find_regexp.
 	    content => undef,	# The string we are tokenizing.
 	    cookie => {},	# Cookies
@@ -135,13 +154,13 @@ defined $DEFAULT_POSTDEREF
 	    failures => 0,	# Number of parse failures.
 	    find => undef,	# String for find_regexp
 	    known => {},	# Known tokenizers, by mode.
+	    location => $args{location},
 	    match => undef,	# Match from find_regexp.
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
 	    postderef => defined $args{postderef} ?
-		$args{postderef} :
-		$DEFAULT_POSTDEREF,
+		$args{postderef} : 1,
 	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    strict => $args{strict},	# like "use re 'strict';".
@@ -150,10 +169,7 @@ defined $DEFAULT_POSTDEREF
 	};
 
 	if ( __instance( $re, 'PPI::Element' ) ) {
-	    defined( my $tokenizer_class = __choose_tokenizer_class(
-		    $re, { parse => 'guess' } ) )
-		or return __set_errstr( ref $re, 'not supported' );
-	    $class eq $tokenizer_class
+	    is_ppi_regexp_element( $re )
 		or return __set_errstr( ref $re, 'not supported by', $class );
 	    # TODO conditionalizstion on PPI class does not really
 	    # belong here, but at the moment I have no other idea of
@@ -207,9 +223,13 @@ sub cookie {
     my ( $self, $name, @args ) = @_;
     defined $name
 	or confess "Programming error - undefined cookie name";
+    if ( $self->{trace} ) {
+	local $" = ', ';
+	warn "cookie( '$name', @args )\n";
+    }
     @args or return $self->{cookie}{$name};
     my $cookie = shift @args;
-    if ( ref $cookie eq 'CODE' ) {
+    if ( CODE_REF eq ref $cookie ) {
 	return ( $self->{cookie}{$name} = $cookie );
     } elsif ( defined $cookie ) {
 	confess "Programming error - cookie must be CODE ref or undef";
@@ -218,6 +238,20 @@ sub cookie {
     }
 }
 
+# NOTE: Currently this is called only against
+# COOKIE_LOOKAROUND_ASSERTION, once in PPIx::Token::GroupType::Assertion
+# to prevent the cookie from being remade if it already exists, and once
+# in PPIx::Regexp::Token::Assertion to determine if \K is inside a
+# lookaround assertion. If it gets used other places, or if there is
+# call for it, I should consider removing the underscores and
+# documenting it as public.
+sub __cookie_exists {
+    my ( $self, $name ) = @_;
+    defined $name
+	or confess "Programming error - undefined cookie name";
+    return $self->{cookie}{$name};
+}
+
 sub default_modifiers {
     my ( $self ) = @_;
     return [ @{ $self->{default_modifiers} } ];
@@ -225,7 +259,7 @@ sub default_modifiers {
 
 sub __effective_modifiers {
     my ( $self ) = @_;
-    'HASH' eq ref $self->{effective_modifiers}
+    HASH_REF eq ref $self->{effective_modifiers}
 	or return {};
     return { %{ $self->{effective_modifiers} } };
 }
@@ -305,7 +339,7 @@ sub find_matching_delimiter {
 sub find_regexp {
     my ( $self, $regexp ) = @_;
 
-    ref $regexp eq 'Regexp'
+    REGEXP_REF eq ref $regexp
 	or confess
 	'Argument is a ', ( ref $regexp || 'scalar' ), ' not a Regexp';
 
@@ -409,6 +443,9 @@ sub make_token {
 	%{ $arg || {} } )
 	or return;
 
+    $self->{index_locations}
+	and $self->_update_location( $token );
+
     $token->significant()
 	and $self->{expect} = undef;
 
@@ -471,6 +508,15 @@ sub modifier_pop {
     return;
 }
 
+sub modifier_seen {
+    my ( $self, $modifier ) = @_;
+    foreach my $mod ( reverse @{ $self->{modifiers} } ) {
+	exists $mod->{$modifier}
+	    and return 1;
+    }
+    return;
+}
+
 sub next_token {
     my ( $self ) = @_;
 
@@ -517,19 +563,6 @@ sub ppi_document {
     return PPI::Document->new( \"$self->{find}" );
 }
 
-sub prior {
-    my ( $self, $method, @args ) = @_;
-    $self->_deprecation_notice( method => 'prior',
-	'prior_significant_token()' );
-    defined $method or return $self->{prior_significant_token};
-    $self->{prior_significant_token}->can( $method )
-	or confess 'Programming error - ',
-	    ( ref $self->{prior_significant_token} ||
-		$self->{prior_significant_token} ),
-	    ' does not support method ', $method;
-    return $self->{prior_significant_token}->$method( @args );
-}
-
 sub prior_significant_token {
     my ( $self, $method, @args ) = @_;
     defined $method or return $self->{prior_significant_token};
@@ -573,10 +606,16 @@ sub prior_significant_token {
 	my ( $self, $token, $iterator ) = @_;
 	$self->{postderef}
 	    or return;
+
 	# Note that if ppi() gets called I have to hold a reference to
 	# the returned object until I am done with all its children.
 	my $ppi;
 	if ( ! defined $iterator ) {
+
+	    # This MUST be done before ppi() is called.
+	    $self->{index_locations}
+		and $self->_update_location( $token );
+
 	    $ppi = $token->ppi();
 	    my @ops = grep { '->' eq $_->content() } @{
 		$ppi->find( 'PPI::Token::Operator' ) || [] };
@@ -590,7 +629,7 @@ sub prior_significant_token {
 	    $iterator = sub {
 		return shift @eles;
 	    };
-	} elsif ( 'CODE' ne ref $iterator ) {
+	} elsif ( CODE_REF ne ref $iterator ) {
 	    confess 'Programming error - Iterator not understood';
 	}
 
@@ -736,9 +775,7 @@ sub tokens {
 
     my %deprecate = (
 	attribute => {
-	},
-	method => {
-	    prior	=> 1,
+	    postderef	=> 1,
 	},
     );
 
@@ -817,18 +854,65 @@ sub __init_error {
     );
 }
 
+sub _update_location {
+    my ( $self, $token ) = @_;
+    $token->{location}	# Idempotent
+	and return;
+    my $loc = $self->{_location} ||= do {
+	my %loc = (
+	    line_content	=> '',
+	    location	=> $self->{location},
+	);
+	if ( __instance( $self->{source}, 'PPI::Element' ) ) {
+	    $loc{location} ||= $self->{source}->location();
+	    if ( my $doc = $self->{source}->document() ) {
+		$loc{tab_width} = $doc->tab_width();
+	    }
+	}
+	$loc{tab_width} ||= 1;
+	\%loc;
+    };
+    $loc->{location}
+	or return;
+    $token->{location} = [ @{ $loc->{location} } ];
+    if ( defined( my $content = $token->content() ) ) {
+	if ( my $newlines = $content =~ tr/\n/\n/ ) {
+	    $loc->{location}[LOCATION_LINE] += $newlines;
+	    $loc->{location}[LOCATION_LOGICAL_LINE] += $newlines;
+	    $content =~ s/ .* \n //smx;
+	    $loc->{location}[LOCATION_CHARACTER] =
+		$loc->{location}[LOCATION_COLUMN] = 1;
+	    $loc->{line_content} = '';
+	}
+	$loc->{location}[LOCATION_CHARACTER] += length $content;
+	$loc->{line_content} .= $content;
+	local $Text::Tabs::tabstop = $loc->{tab_width};
+	$loc->{location}[LOCATION_COLUMN] = 1 + length Text::Tabs::expand(
+	    $loc->{line_content} );
+    }
+    return;
+}
+
 sub __PPIX_TOKENIZER__init {
     my ( $self ) = @_;
 
     $self->find_regexp(
-	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) (?: [^\w\s] ) }smx )
+	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) ( . ) }smx )
 	or return $self->__init_error();
 
-    my ( $leading_white, $type, $next_white ) = $self->capture();
+    my ( $leading_white, $type, $next_white, $delim_start ) = $self->capture();
 
     defined $type
 	or $type = '';
 
+    $type
+	or $delim_start =~ m< \A [/?] \z >smx
+	or return $self->__init_error();
+    $type
+	and not $next_white
+	and $delim_start =~ m< \A \w \z >smx
+	and return $self->__init_error();
+
     $self->{type} = $type;
 
     my @tokens;
@@ -842,13 +926,10 @@ sub __PPIX_TOKENIZER__init {
 	and push @tokens, $self->make_token( length $next_white,
 	'PPIx::Regexp::Token::Whitespace' );
 
-    $self->{delimiter_start} = substr
-	$self->{content},
-	$self->{cursor_curr},
-	1;
+    $self->{delimiter_start} = $delim_start;
 
     $self->{trace}
-	and warn "Tokenizer found regexp start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
+	and warn "Tokenizer found regexp start delimiter '$delim_start' at $self->{cursor_curr}\n";
 
     if ( my $offset = $self->find_matching_delimiter() ) {
 	my $cursor_limit = $self->{cursor_curr} + $offset;
@@ -924,6 +1005,13 @@ sub __PPIX_TOKENIZER__init {
     }
 
     {
+	# We have to instantiate the trailing tokens now so we can
+	# figure out what modifiers are in effect. But we can't
+	# index their locations (if desired) because they are being
+	# instantiated out of order
+
+	local $self->{index_locations} = 0;
+
 	my @mods = @{ $self->{default_modifiers} };
 	pos $self->{content} = $self->{cursor_modifiers};
 	local $self->{cursor_curr} = $self->{cursor_modifiers};
@@ -1100,8 +1188,8 @@ sub __PPIX_TOKENIZER__finish {
 
 	# We are out of string. Add the trailing tokens (created when we
 	# did the initial bracket scan) and close up shop.
-
-	push @tokens, @{ delete $self->{trailing_tokens} };
+	
+	push @tokens, $self->_get_trailing_tokens();
 
 	$self->_set_mode( 'kaput' );
 
@@ -1159,7 +1247,7 @@ sub __PPIX_TOKENIZER__finish {
 	    $self->{cursor_limit} = length $self->{content};
 	    push @tokens, $self->make_token( 1,
 		'PPIx::Regexp::Token::Delimiter' ),
-		@{ delete $self->{trailing_tokens} };
+		$self->_get_trailing_tokens();
 	    $self->_set_mode( 'kaput' );
 	} else {
 	    # Put our mode to replacement.
@@ -1172,6 +1260,19 @@ sub __PPIX_TOKENIZER__finish {
 
 }
 
+# To common processing on trailing tokens.
+sub _get_trailing_tokens {
+    my ( $self ) = @_;
+    if ( $self->{index_locations} ) {
+	# We turned off index_locations when these were created, because
+	# they were done out of order. Fix that now.
+	foreach my $token ( @{ $self->{trailing_tokens} } ) {
+	    $self->_update_location( $token );
+	}
+    }
+    return @{ delete $self->{trailing_tokens} };
+}
+
 1;
 
 __END__
@@ -1229,8 +1330,16 @@ This option specifies the encoding of the string to be tokenized. If
 specified, an C<Encode::decode> is done on the string (or the C<content>
 of the PPI class) before it is tokenized.
 
+=item index_locations
+
+This Boolean option specifies that the locations of the generated tokens
+are to be computed.
+
 =item postderef boolean
 
+B<THIS ARGUMENT IS DEPRECATED>.
+See L<DEPRECATION NOTICE|PPIx::Regexp/DEPRECATION NOTICE> in L<PPIx::Regexp|PPIx::Regexp> for the details.
+
 This option specifies whether the tokenizer recognizes postfix
 dereferencing. See the L<PPIx::Regexp|PPIx::Regexp>
 L<new()|PPIx::Regexp/new> documentation for the details.
@@ -1318,6 +1427,9 @@ appears. In this case an exception will be thrown if you specify a
 multi-character modifier (e.g.  C<'ee*'>), or if you specify one of the
 match semantics modifiers (e.g.  C<'a*'>).
 
+If called by an external tokenizer, this method returns true if if the
+given modifier was true at the current point in the tokenization.
+
 =head2 next_token
 
  my $token = $tokenizer->next_token();
@@ -1415,8 +1527,8 @@ can be abbreviated by removing the leading 'PPIx::Regexp::'.
 If no class is specified, this method does nothing.
 
 The expectation lasts from the next time L</get_token> is called until
-the next time L<make_token> makes a significant token, or until the next
-C<expect> call if that is done sooner.
+the next time L</make_token> makes a significant token, or until the
+next C<expect> call if that is done sooner.
 
 =head2 find_regexp
 
@@ -1552,6 +1664,17 @@ whose content is ')'.
 Note that this method will never pop the last modifier item off the
 stack, to guard against unmatched right parentheses.
 
+=head2 modifier_seen
+
+ $tokenizer->modifier_seen( 'i' )
+     and print "/i was seen at some point.\n";
+
+Unlike L<modifier()|/modifier>, this method returns a true value if the
+given modifier has been seen in any scope visible from the current
+location in the parse. There is no magic for group match semantics (
+/a, /aa, /d, /l, /u) or modifiers that can be repeated, like /x and /xx,
+or /e and /ee.
+
 =head2 peek
 
  my $character = $tokenizer->peek();
@@ -1568,30 +1691,6 @@ C<undef> is returned.
 This method makes a PPI document out of the remainder of the string, and
 returns it.
 
-=head2 prior
-
- $tokenizer->prior( 'can_be_quantified' )
-    and print "The prior token can be quantified.\n";
-
-This method is deprecated in favor of
-L<prior_significant_tokrn()|/prior_significant_token>. It will warn on
-the first use. Six months after the release of version 0.050_01
-it will start warning on every use. Six months after that a fatal
-exception will be thrown when it is called. I am not sure I need to put
-this though a deprecation cycle, given that this method is documented as
-not being part of the public interface, but I choose to err on the side
-of caution.
-
-This method calls the named method on the most-recently-instantiated
-significant token, and returns the result. Any arguments subsequent to
-the method name will be passed to the method.
-
-Because this method is designed to be used within the tokenizing system,
-it will die horribly if the named method does not exist.
-
-If called with no arguments at all the most-recently-instantiated
-significant token is returned.
-
 =head2 prior_significant_token
 
  $tokenizer->prior_significant_token( 'can_be_quantified' )
@@ -1628,7 +1727,8 @@ troubleshoot funny output from the tokenizer.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -1636,7 +1736,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
